package sun.security.tools;

import java.io.IOException;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ResourceBundle;
import java.io.FileInputStream;
import java.io.File;
import java.security.KeyStore;
import java.util.Locale;
import java.security.cert.X509Certificate;
import java.text.Collator;

public class KeyStoreUtil
{
    private static final String JKS = "jks";
    private static final Collator collator;
    
    private KeyStoreUtil() {
    }
    
    public static boolean isSelfSigned(X509Certificate x509Certificate) {
        return signedBy(x509Certificate, x509Certificate);
    }
    
    public static boolean signedBy(X509Certificate x509Certificate, X509Certificate x509Certificate2) {
        if (!x509Certificate2.getSubjectX500Principal().equals(x509Certificate.getIssuerX500Principal())) {
            return false;
        }
        try {
            x509Certificate.verify(x509Certificate2.getPublicKey());
            return true;
        }
        catch (Exception ex) {
            return false;
        }
    }
    
    public static boolean isWindowsKeyStore(String s) {
        return s != null && (s.equalsIgnoreCase("Windows-MY") || s.equalsIgnoreCase("Windows-ROOT"));
    }
    
    public static String niceStoreTypeName(String s) {
        if (s.equalsIgnoreCase("Windows-MY")) {
            return "Windows-MY";
        }
        if (s.equalsIgnoreCase("Windows-ROOT")) {
            return "Windows-ROOT";
        }
        return s.toUpperCase(Locale.ENGLISH);
    }
    
    public static KeyStore getCacertsKeyStore() throws Exception {
        String separator = File.separator;
        File file = new File(System.getProperty("java.home") + separator + "lib" + separator + "security" + separator + "cacerts");
        if (!file.exists()) {
            return null;
        }
        KeyStore instance = null;
        try (final FileInputStream stream = new FileInputStream(file)) {
            instance = KeyStore.getInstance("jks");
            instance.load(stream, (char[])null);
        }
        return instance;
    }
    
    public static char[] getPassWithModifier(String str, String str2, ResourceBundle resourceBundle) {
        if (str == null) {
            return str2.toCharArray();
        }
        if (KeyStoreUtil.collator.compare(str, "env") == 0) {
            String getenv = System.getenv(str2);
            if (getenv == null) {
                System.err.println(resourceBundle.getString("Cannot.find.environment.variable.") + str2);
                return null;
            }
            return getenv.toCharArray();
        }
        else {
            if (KeyStoreUtil.collator.compare(str, "file") == 0) {
                try {
                    URL url;
                    try {
                        url = new URL(str2);
                    }
                    catch (MalformedURLException ex) {
                        File file = new File(str2);
                        if (file.exists()) {
                            url = file.toURI().toURL();
                        }
                        else {
                            System.err.println(resourceBundle.getString("Cannot.find.file.") + str2);
                            return null;
                        }
                    }
                    try (final Object o = new BufferedReader(new InputStreamReader(url.openStream()))) {
                        String line = o.readLine();
                        if (line == null) {
                            return new char[0];
                        }
                        else {
                            return line.toCharArray();
                        }
                    }
                }
                catch (IOException x) {
                    System.err.println(x);
                    return null;
                }
            }
            System.err.println(resourceBundle.getString("Unknown.password.type.") + str);
            return null;
        }
    }
    
    static {
        (collator = Collator.getInstance()).setStrength(0);
    }
}
